package LATMOS::Accounts::Web::Controller::Create;

use strict;
use warnings;
use base 'LATMOS::Accounts::Web::Controller';
use LATMOS::Accounts::Utils;

=head1 NAME

LATMOS::Accounts::Web::Controller::Create - Catalyst Controller

=head1 DESCRIPTION

Catalyst Controller.

=head1 METHODS

=cut


=head2 index 

=cut

sub index : Private {
    my ( $self, $c ) = @_;

    $c->response->body('Matched LATMOS::Accounts::Web::Controller::Create in Create.');
}

sub user : Local {
    my ( $self, $c ) = @_;

    my $base = $c->model('Accounts')->db;
    $c->stash->{form} = $c->model('AttrForms', undef, 'user', $base);
    for ($c->req->param('step') || '') {
        /^1$/ and do {
            $c->stash->{step} = 2;
            my $acc = $c->model('Accounts')->accounts;
            foreach ($acc->Parameters('_defattr_')) {
                if (/^user\.(.*)/) {
                    $c->req->params->{$1} ||= $acc->val('_defattr_', $_);
                }
            }
            $c->req->params->{exported} = 1;
            if (! $c->req->params->{id}) {
                for (1) {
                    my $login;
                    if ($c->req->param('sn')) {
                        $login = lc(to_ascii($c->req->param('sn')));
                        length($login) > 10 and $login = substr($login, 0, 8);
                        $base->get_object('user', $login) or do {
                            $c->req->params->{id} = $login;
                            last;
                        };
                        if ($c->req->param('givenName')) {
                            length($login) > 8 and $login = substr($login, 0, 8);
                            $login .= substr(lc(to_ascii($c->req->param('givenName'))), 0, 1);
                            $base->get_object('user', $login) or do {
                                $c->req->params->{id} = $login;
                                last;
                            };
                        }
                    }
                }

                my $mailid = $c->req->params->{givenName} && $c->req->params->{sn}
                ? sprintf('%s.%s',
                    to_ascii(lc($c->req->params->{givenName})),
                    to_ascii(lc($c->req->params->{sn})),)
                : undef;

                if ($mailid &&
                    $base->is_supported_object('aliases') &&
                    ! $base->get_object('aliases', $mailid)) {
                    if ($base->get_field_name('user', 'mail', 'write')) {
                        if ($base->{defattr}{'user.maildomain'}) {
                            $c->req->params->{mail} ||= sprintf('%s@%s',
                                $mailid,
                                $base->{defattr}{'user.maildomain'});
                        }
                    }
                    if ($base->get_field_name('user', 'aliases', 'write')) {
                        $c->req->params->{aliases} ||= $mailid;
                    }
                    warn $base->get_field_name('user', 'revaliases', 'write');
                    if ($base->get_field_name('user', 'revaliases', 'write')) {
                        $c->req->params->{revaliases} ||= $mailid;
                    }
                }
            }
            last;
        };
        /^2$/ and do {
            $c->stash->{step} = 2;
            $c->req->params->{id} or return;
            $base->get_object('user', $c->req->params->{id}) and do {
                $c->stash->{idexists} = 1;
                return;
            };
            $base->create_c_object('user', $c->req->params->{id},
                %{ $c->req->params },
                exported => $c->req->param('exported') ? 1 : 0,
            ) or return;
            $base->commit;
            $c->res->redirect($c->uri_for('/users', $c->req->params->{id}));
            last;
        };
    }
}

sub group : Local {
    my ( $self, $c ) = @_;

    my $base = $c->model('Accounts')->db;
    $c->stash->{form} = $c->model('AttrForms', undef, 'group', $base);
    if (!exists($c->req->params->{id})) {
        $c->req->params->{exported} = 1;
    }

    if ($c->req->params->{id}) {
        $base->get_object('group', $c->req->params->{id}) and do {
            $c->stash->{idexists} = 1;
            return;
        };
        $base->create_c_object('group', $c->req->params->{id},
            %{ $c->req->params },
            exported => $c->req->param('exported') ? 1 : 0,
        ) or return;
        $base->commit;
        $c->res->redirect($c->uri_for('/groups', $c->req->params->{id}));
    }
}

=head1 AUTHOR

Thauvin Olivier

=head1 LICENSE

This library is free software, you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

1;
